# File Management — REST API Reference

- [File Upload](upload.md) — Uploading files (multipart, presigned URL, base64)
- [File API](files.md) — Listing, retrieving, and deleting files
- [QR Code API](qrcode.md) — Generating QR codes
